/*
 * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
 *                         University Research and Technology
 *                         Corporation.  All rights reserved.
 * Copyright (c) 2004-2006 The University of Tennessee and The University
 *                         of Tennessee Research Foundation.  All rights
 *                         reserved.
 * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
 *                         University of Stuttgart.  All rights reserved.
 * Copyright (c) 2004-2005 The Regents of the University of California.
 *                         All rights reserved.
 * $COPYRIGHT$
 * 
 * Additional copyrights may follow
 * 
 * $HEADER$
 */

#ifndef OPAL_MCA_TIMER_WINDOWS_COMPONENT_H
#define OPAL_MCA_TIMER_WINDOWS_COMPONENT_H

#include "opal_config.h"
#include "opal/mca/timer/windows/timer_windows.h"

BEGIN_C_DECLS

OPAL_DECLSPEC extern const opal_timer_base_component_2_0_0_t mca_timer_windows_component;

END_C_DECLS

#endif
